==> flink-1.18.1-src.tgz: flink-1.18.1/flink-table/flink-table-planner/src/test/java/org/apache/flink/table/planner/parse/ResetOperationParseStrategyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.parse;

import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** Tests for {@link ResetOperationParseStrategy}. */
public class ResetOperationParseStrategyTest {

    @Test
    public void testMatches() {
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET table.planner")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET;")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET table.planner;")).isTrue();
    }

    @Test
    public void testDoesNotMatchQuotedKey() {
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET 'table.planner'")).isFalse();
    }
}

==> flink-2.0.1-src.tgz: flink-2.0.1/flink-table/flink-table-planner/src/test/java/org/apache/flink/table/planner/parse/ResetOperationParseStrategyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.parse;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** Tests for {@link ResetOperationParseStrategy}. */
class ResetOperationParseStrategyTest {

    @Test
    void testMatches() {
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET table.planner")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET;")).isTrue();
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET table.planner;")).isTrue();
    }

    @Test
    void testDoesNotMatchQuotedKey() {
        assertThat(ResetOperationParseStrategy.INSTANCE.match("RESET 'table.planner'")).isFalse();
    }
}
